%define debug_package %{nil}

%define version_major 5.0
%define version_minor 15.2
%define version_main %{version}
%define version_lite %{version}
%define ipv6_ver %{version}
%define ipv6_lite_ver %{version}
%define sha1sums_ver %{version}
%define ftp_ver %{version_major}.15
%define ftp_path ftp://ftp.shorewall.net/pub/shorewall/%{version_major}/%{name}-%{ftp_ver}

%define name6 %{name}6

Summary:	Iptables-based firewall for Linux systems
Name:		shorewall
Version:	%{version_major}.%{version_minor}
Release:	%mkrel 1
License:	GPLv2+ and LGPLv2.1+
Group:		System/Servers
URL:		http://www.shorewall.net/
Source0:	%{ftp_path}/%{name}-%{version}.tar.bz2
Source1:	%{ftp_path}/%{name}-lite-%{version_lite}.tar.bz2
Source2:	%{ftp_path}/%{name}-docs-html-%{version}.tar.bz2
Source3:	%{ftp_path}/%{name6}-%{ipv6_ver}.tar.bz2
Source4:	%{ftp_path}/%{name6}-lite-%{ipv6_lite_ver}.tar.bz2
Source5:	%{ftp_path}/%{sha1sums_ver}.sha1sums
Source6:	%{ftp_path}/%{name}-core-%{version}.tar.bz2
Patch4:		%{name}-4.4.23-allow-netmask-0.patch
Patch6:		shorewall-4.6.13.1-mga_fix.patch
Requires:	iptables
Requires:	iproute2
Requires:	shorewall-core = %{version}-%{release}
Requires(post):	rpm-helper
Requires(preun): rpm-helper
BuildConflicts:	apt-common
BuildArch:	noarch

%description
The Shoreline Firewall, more commonly known as "Shorewall", is a Netfilter
(iptables) based firewall that can be used on a dedicated firewall system,
a multi-function gateway/ router/server or on a standalone GNU/Linux system.

%package core
Summary:	Shorewall core libraries
Group:		System/Servers
Conflicts:	shorewall < 4.5-3
Requires(post):	rpm-helper
Requires(preun):	rpm-helper

%description core
An IPv6 enabled and capable Shoreline Firewall.


%package ipv6
Summary:	IPv6 capable Shorewall
Group:		System/Servers
Requires:	%{name} = %{version}-%{release}
Requires:	iptables-ipv6
Requires:	iproute2
Requires:	shorewall-core
Requires(post):	rpm-helper
Requires(preun):	rpm-helper

%description ipv6
An IPv6 enabled and capable Shoreline Firewall.

%package ipv6-lite
Summary:	Lite version of ipv6 shorewall
Group:		System/Servers
Requires:	%{name}-ipv6 = %{version}-%{release}
Requires:	shorewall-core
Requires(post):	rpm-helper
Requires(preun):	rpm-helper

%description ipv6-lite
Shorewall IPv6 Lite is a companion product to Shorewall IPv6 that allows 
network administrators to centralize the configuration of Shorewall-based
firewalls.

%package lite
Summary:	Lite version of shorewall
Group:		System/Servers
Requires:	%{name} = %{version}-%{release}
Requires:	shorewall-core
Requires(post):	rpm-helper
Requires(preun):	rpm-helper

%description lite
Shorewall Lite is a companion product to Shorewall that allows network
administrators to centralize the configuration of Shorewall-based firewalls.

%package doc
Summary:	Firewall scripts
Group:		System/Servers

%description doc 
The Shoreline Firewall, more commonly known as "Shorewall", is a Netfilter
(iptables) based firewall that can be used on a dedicated firewall system,
a multi-function gateway/ router/server or on a standalone GNU/Linux system.

This package contains the docs.

%prep
%setup -q -c -n %{name}-%{version}
%setup -q -T -D -a 1
%setup -q -T -D -a 2
%setup -q -T -D -a 3
%setup -q -T -D -a 4
%setup -q -T -D -a 6

pushd %{name}-%{version_main}
%patch4 -p1 -b .allow-netmask-0
popd

# use one patch for all (easiest fix)
for i in shorewall-%{version} shorewall6-%{version} \
    shorewall6-lite-%{version} shorewall-core-%{version} \
    shorewall-lite-%{version}; do
pushd $i
%patch6 -p1
popd
done

# another fixup
for i in shorewall-%{version} shorewall6-%{version} \
    shorewall6-lite-%{version}  shorewall-lite-%{version}; do
pushd $i
cp default.debian sysconfig
popd
done

%build
# (tpg) we do nothing here

%install
mkdir -p %{buildroot}%{_unitdir}

export PREFIX=%{buildroot}
export OWNER=`id -n -u`
export GROUP=`id -n -g`

export CONFDIR=%{_sysconfdir}/%{name}

pushd %{name}-core-%{version_main}
./configure.pl INITFILE= SYSTEMD=%{_unitdir} SBINDIR=%{_sbindir} LIBEXEC=%{_libexecdir}
DESTDIR=%{buildroot} ./install.sh shorewallrc.redhat
popd

pushd %{name}-%{version_main}
# (blino) enable startup (new setting as of 2.1.3)
perl -pi -e 's/STARTUP_ENABLED=.*/STARTUP_ENABLED=Yes/' configfiles/%{name}.conf

# Keep synced with net.ipv4.ip_forward var in /etc/sysctl.conf
perl -pi -e 's/IP_FORWARDING=.*/IP_FORWARDING=Keep/' configfiles/%{name}.conf

# blank Internal option	 
perl -pi -e 's/TC_ENABLED=Internal/TC_ENABLED=/' configfiles/%{name}.conf

# (tpg) do the optimizations
perl -pi -e 's/OPTIMIZE=.*/OPTIMIZE=1/' configfiles/%{name}.conf

# (tpg) set config path
perl -pi -e 's#CONFIG_PATH=.*#CONFIG_PATH=configfiles/%{/g_sysconfdir}/%{name}#' configpath

# (lmenut) mga kernel modules are compressed by default (mga #1147)
perl -pi -e 's#MODULE_SUFFIX=.*#MODULE_SUFFIX="ko ko.xz ko.gz"#' configfiles/%{name}.conf

# (alien) have accounting by default in the mangle table
perl -pi -e 's#ACCOUNTING_TABLE=.*#ACCOUNTING_TABLE=mangle#' configfiles/%{name}.conf

./configure.pl INITFILE= SYSTEMD=%{_unitdir} SBINDIR=%{_sbindir} LIBEXEC=%{_libexecdir}

# let's do the install
DESTDIR=%{buildroot} ./install.sh shorewallrc.redhat
install -m 644 *.service %{buildroot}%{_unitdir}
popd

#(tpg) IPv6
pushd %{name6}-%{ipv6_ver}
# (blino) enable startup (new setting as of 2.1.3)
perl -pi -e 's/STARTUP_ENABLED=.*/STARTUP_ENABLED=Yes/' configfiles/%{name6}.conf
# Keep synced with net.ipv4.ip_forward var in /etc/sysctl.conf
perl -pi -e 's/IP_FORWARDING=.*/IP_FORWARDING=Keep/' configfiles/%{name6}.conf
# (lmenut) mga kernel modules are compressed by default (mga #1147)
perl -pi -e 's#MODULE_SUFFIX=.*#MODULE_SUFFIX="ko ko.xz ko.gz"#' configfiles/%{name6}.conf
./configure.pl INITFILE= SYSTEMD=%{_unitdir} SBINDIR=%{_sbindir} LIBEXEC=%{_libexecdir}
DESTDIR=%{buildroot} ./install.sh
install -m 644 *.service %{buildroot}%{_unitdir}
popd

pushd %{name6}-lite-%{ipv6_lite_ver}
./configure.pl INITFILE= SYSTEMD=%{_unitdir} SBINDIR=%{_sbindir} LIBEXEC=%{_libexecdir}
DESTDIR=%{buildroot} ./install.sh
install -m 644 *.service %{buildroot}%{_unitdir}
popd

pushd %{name}-lite-%{version_lite}
./configure.pl INITFILE= SYSTEMD=%{_unitdir} SBINDIR=%{_sbindir} LIBEXEC=%{_libexecdir}
DESTDIR=%{buildroot} ./install.sh
install -m 644 *.service %{buildroot}%{_unitdir}
popd

# Suppress automatic replacement of "echo" by "gprintf" in the shorewall
# startup script by RPM. This automatic replacement is broken.
export DONT_GPRINTIFY=1

#(tpg) looks like these files are needed
touch %{buildroot}/%{_var}/lib/shorewall/{chains,nat,proxyarp,restarted,zones,restore-base,restore-tail,state,.modules,.modulesdir,.iptables-restore-input,.start,.restart,.restore}
touch %{buildroot}/%{_var}/lib/shorewall-lite/firewall

#(tpg) ipv6
touch %{buildroot}/%{_var}/lib/%{name6}/{chains,restarted,zones,restore-base,restore-tail,state,.modules,.modulesdir,.iptables-restore-input,.start,.restart,.restore}
touch %{buildroot}/%{_var}/lib/%{name6}-lite/firewall

#remove unused files because of %exclude misbehaviour
rm -f %{buildroot}%{_datadir}/%{name6}/configfiles/*
rm -f %{buildroot}%{_datadir}/shorewall/configfiles/*

# Remove sysv init file
rm -f %{buildroot}%{_initrddir}/%{name}

# Don't install systemd service in /lib/systemd
rm -f %{buildroot}/lib/systemd/system/shorewall.service
rm -f %{buildroot}/lib/systemd/system/shorewall-lite.service
rm -f %{buildroot}/lib/systemd/system/shorewall6.service
rm -f %{buildroot}/lib/systemd/system/shorewall6-lite.service

# (tmb) allow outgoing traffic on any interface by default (mga#10947)
# (cg) drop the ?FORMAT 2 line as it disagrees with 'detect' (mga#11928)
perl -n -i -e 'print unless m!^?FORMAT 2$!' %{buildroot}%{_sysconfdir}/%{name}/interfaces
echo "net	+	detect" >> %{buildroot}%{_sysconfdir}/%{name}/interfaces
perl -n -i -e 'print unless m!^?FORMAT 2$!' %{buildroot}%{_sysconfdir}/%{name6}/interfaces
echo "net	+	detect" >> %{buildroot}%{_sysconfdir}/%{name6}/interfaces

%post
if [ "$1" -gt 1 ] ; then
  perl -pi -e 's#MODULE_SUFFIX=ko$#MODULE_SUFFIX="ko ko.xz ko.gz"#' %{_sysconfdir}/%{name}/%{name}.conf
  perl -pi -e 's#MODULE_SUFFIX=\"ko ko.gz\"$#MODULE_SUFFIX="ko ko.xz ko.gz"#' %{_sysconfdir}/%{name}/%{name}.conf
fi
%_post_service shorewall

%create_ghostfile %{_var}/lib/%{name}/chains root root 644
%create_ghostfile %{_var}/lib/%{name}/nat root root 644
%create_ghostfile %{_var}/lib/%{name}/proxyarp root root 644
%create_ghostfile %{_var}/lib/%{name}/restarted root root 644
%create_ghostfile %{_var}/lib/%{name}/zones root root 644
%create_ghostfile %{_var}/lib/%{name}/restore-base root root 644
%create_ghostfile %{_var}/lib/%{name}/restore-tail root root 644
%create_ghostfile %{_var}/lib/%{name}/state root root 644
%create_ghostfile %{_var}/lib/%{name}/.modules root root 644
%create_ghostfile %{_var}/lib/%{name}/.modulesdir root root 644
%create_ghostfile %{_var}/lib/%{name}/.iptables-restore-input root root 644
%create_ghostfile %{_var}/lib/%{name}/.restart root root 700
%create_ghostfile %{_var}/lib/%{name}/.restore root root 700
%create_ghostfile %{_var}/lib/%{name}/.start root root 700

%preun
%_preun_service %{name}
if [ $1 = 0 ] ; then
  rm -f %{_sysconfdir}/%{name}/startup_disabled
  rm -f %{_var}/lib/%{name}/*
fi

%post lite
%_post_service %{name}-lite
%create_ghostfile %{_var}/lib/%{name}-lite/firewall root root 644

%preun lite
%_preun_service %{name}-lite

%post ipv6
if [ "$1" -gt 1 ] ; then
  perl -pi -e 's#MODULE_SUFFIX=ko$#MODULE_SUFFIX="ko ko.xz ko.gz"#' %{_sysconfdir}/%{name6}/%{name6}.conf
  perl -pi -e 's#MODULE_SUFFIX=\"ko ko.gz\"$#MODULE_SUFFIX="ko ko.xz ko.gz"#' %{_sysconfdir}/%{name6}/%{name6}.conf
fi
%_post_service %{name6}

%create_ghostfile %{_var}/lib/%{name6}/chains root root 644
%create_ghostfile %{_var}/lib/%{name6}/restarted root root 644
%create_ghostfile %{_var}/lib/%{name6}/zones root root 644
%create_ghostfile %{_var}/lib/%{name6}/restore-base root root 644
%create_ghostfile %{_var}/lib/%{name6}/restore-tail root root 644
%create_ghostfile %{_var}/lib/%{name6}/state root root 644
%create_ghostfile %{_var}/lib/%{name6}/.modules root root 644
%create_ghostfile %{_var}/lib/%{name6}/.modulesdir root root 644
%create_ghostfile %{_var}/lib/%{name6}/.iptables-restore-input root root 644
%create_ghostfile %{_var}/lib/%{name6}/.restart root root 700
%create_ghostfile %{_var}/lib/%{name6}/.restore root root 700
%create_ghostfile %{_var}/lib/%{name6}/.start root root 700

%preun ipv6
%_preun_service %{name6}
if [ $1 = 0 ] ; then
  rm -f %{_sysconfdir}/%{name6}/startup_disabled
  rm -f %{_var}/lib/%{name6}/*
fi

%post ipv6-lite
%_post_service %{name6}-lite
%create_ghostfile %{_var}/lib/%{name6}-lite/firewall root root 644

%preun ipv6-lite
%_preun_service %{name6}-lite

%files
%doc %{name}-%{version_main}/{changelog.txt,releasenotes.txt,Samples}
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%dir %{_datadir}/%{name}
%dir %attr(755,root,root) %{_var}/lib/%{name}
%ghost %{_var}/lib/%{name}/*
%ghost %{_var}/lib/%{name}/.??*
%config %{_sysconfdir}/logrotate.d/%{name}
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/%{name}
#%attr(755,root,root) %{_sbindir}/%{name}
%attr(755,root,root) /sbin/%{name}
%{_datadir}/%{name}/action*
%{_datadir}/%{name}/configpath
%dir %{_datadir}/%{name}/deprecated
%{_datadir}/%{name}/deprecated/action.A_Reject
%{_datadir}/%{name}/deprecated/macro.SNMPTrap
%{_datadir}/%{name}/helpers
%{_datadir}/%{name}/lib.cli-std
%{_datadir}/%{name}/lib.runtime
%{_datadir}/%{name}/macro.*
%{_datadir}/%{name}/modules*
%{_datadir}/%{name}/version
%{_libexecdir}/%{name}/getparams
%{_libexecdir}/%{name}/wait4ifup
%{_mandir}/man5/%{name}-accounting.5.*
%{_mandir}/man5/%{name}-actions.5.*
#{_mandir}/man5/%{name}-blacklist.5.*
%{_mandir}/man5/%{name}-ecn.5.*
%{_mandir}/man5/%{name}-exclusion.5.*
%{_mandir}/man5/%{name}-hosts.5.*
%{_mandir}/man5/%{name}-interfaces.5.*
%{_mandir}/man5/%{name}-ipsets.5.*
%{_mandir}/man5/%{name}-maclist.5.*
%{_mandir}/man5/%{name}-mangle.5.*
%{_mandir}/man5/%{name}-masq.5.*
%{_mandir}/man5/%{name}-modules.5.*
%{_mandir}/man5/%{name}-nat.5.*
%{_mandir}/man5/%{name}-nesting.5.*
#%{_mandir}/man5/%{name}-notrack.5.*
%{_mandir}/man5/%{name}-netmap.5.*
%{_mandir}/man5/%{name}-params.5.*
%{_mandir}/man5/%{name}-policy.5.*
%{_mandir}/man5/%{name}-providers.5.*
%{_mandir}/man5/%{name}-proxyarp.5.*
#%{_mandir}/man5/%{name}-route_rules.5.*
%{_mandir}/man5/%{name}-routes.5.*
#{_mandir}/man5/%{name}-routestopped.5.*
%{_mandir}/man5/%{name}-rules.5.*
%{_mandir}/man5/%{name}-secmarks.5.*
%{_mandir}/man5/%{name}-snat.5.*
%{_mandir}/man5/%{name}-tcclasses.5.*
%{_mandir}/man5/%{name}-tcinterfaces.5.*
%{_mandir}/man5/%{name}-tcpri.5.*
%{_mandir}/man5/%{name}-tcdevices.5.*
%{_mandir}/man5/%{name}-tcfilters.5.*
#{_mandir}/man5/%{name}-tcrules.5.*
#{_mandir}/man5/%{name}-tos.5.*
%{_mandir}/man5/%{name}-tunnels.5.*
%{_mandir}/man5/%{name}-vardir.5.*
%{_mandir}/man5/%{name}-zones.5.*
%{_mandir}/man5/%{name}.conf.5.*
%{_mandir}/man8/%{name}.8.*
%{_mandir}/man8/%{name}-init.8.*
%{_mandir}/man5/%{name}-blrules.5.*
%{_mandir}/man5/%{name}-conntrack.5.*
%{_mandir}/man5/%{name}-rtrules.5.*
%{_mandir}/man5/%{name}-stoppedrules.5.*
%{_mandir}/man5/%{name}-arprules.5*
#%dir %{_datadir}/shorewall/Shorewall
%{_datadir}/perl5/vendor_perl/Shorewall/*.pm
%{_libexecdir}/shorewall/compiler.pl
%{_datadir}/shorewall/prog.footer
#%{_datadir}/shorewall/prog.header
%{_unitdir}/shorewall.service

%files ipv6
%doc %{name6}-%{ipv6_ver}/{changelog.txt,releasenotes.txt,tunnel,ipsecvpn,Samples6}
%config(noreplace) %{_sysconfdir}/sysconfig/%{name6}
%dir %{_sysconfdir}/%{name6}
%dir %{_datadir}/%{name6}
%dir %attr(755,root,root) %{_var}/lib/%{name6}
%ghost %{_var}/lib/%{name6}/*
%ghost %{_var}/lib/%{name6}/.??*
%config(noreplace) %{_sysconfdir}/%{name6}/*
%config %{_sysconfdir}/logrotate.d/%{name6}
%attr(755,root,root) %{_sbindir}/%{name6}
%{_datadir}/%{name6}/action*
#%{_datadir}/%{name}/prog.footer6
#%{_datadir}/%{name}/prog.header6
%{_datadir}/%{name6}/configpath
%{_datadir}/%{name6}/functions
%{_datadir}/%{name6}/helpers
%{_datadir}/%{name6}/lib.*
%{_datadir}/%{name6}/macro.*
%{_datadir}/%{name6}/modules*
%{_datadir}/%{name6}/version
#%{_libexecdir}/%{name6}/wait4ifup
%{_mandir}/man5/%{name6}-accounting.5.*
%{_mandir}/man5/%{name6}-actions.5.*
#{_mandir}/man5/%{name6}-blacklist.5.*
%{_mandir}/man5/%{name6}-exclusion.5.*
%{_mandir}/man5/%{name6}-hosts.5.*
%{_mandir}/man5/%{name6}-interfaces.5.*
%{_mandir}/man5/%{name6}-ipsets.5.*
%{_mandir}/man5/%{name6}-maclist.5.*
%{_mandir}/man5/%{name6}-mangle.5.*
%{_mandir}/man5/%{name6}-modules.5.*
%{_mandir}/man5/%{name6}-nesting.5.*
%{_mandir}/man5/%{name6}-nat.5.*
#%{_mandir}/man5/%{name6}-notrack.5.*
%{_mandir}/man5/%{name6}-params.5.*
%{_mandir}/man5/%{name6}-policy.5.*
%{_mandir}/man5/%{name6}-providers.5.*
%{_mandir}/man5/%{name6}-proxyndp.5.*
#%{_mandir}/man5/%{name6}-route_rules.5.*
%{_mandir}/man5/%{name6}-routes.5.*
#{_mandir}/man5/%{name6}-routestopped.5.*
%{_mandir}/man5/%{name6}-rules.5.*
%{_mandir}/man5/%{name6}-secmarks.5.*
%{_mandir}/man5/%{name6}-snat.5.*
%{_mandir}/man5/%{name6}-tcclasses.5.*
%{_mandir}/man5/%{name6}-tcdevices.5.*
%{_mandir}/man5/%{name6}-tcfilters.5.*
%{_mandir}/man5/%{name6}-tcinterfaces.5.*
%{_mandir}/man5/%{name6}-tcpri.5.*
#{_mandir}/man5/%{name6}-tcrules.5.*
#{_mandir}/man5/%{name6}-tos.5.*
%{_mandir}/man5/%{name6}-tunnels.5.*
%{_mandir}/man5/%{name6}-vardir.5.*
%{_mandir}/man5/%{name6}-zones.5.*
%{_mandir}/man5/%{name6}.conf.5.*
%{_mandir}/man8/%{name6}.8.*
%{_mandir}/man5/%{name6}-blrules.5.*
%{_mandir}/man5/%{name6}-conntrack.5.*
%{_mandir}/man5/%{name6}-rtrules.5.*
%{_mandir}/man5/%{name6}-stoppedrules.5.*
%{_mandir}/man5/%{name6}-netmap.5.*
%{_mandir}/man5/%{name6}-masq.5*
%{_unitdir}/shorewall6.service

%files lite
%doc %{name}-lite-%{version_lite}/*.txt
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}-lite
%dir %{_datadir}/%{name}-lite
%dir %attr(755,root,root) %{_var}/lib/%{name}-lite
%ghost %{_var}/lib/%{name}-lite/*
%config(noreplace) %{_sysconfdir}/%{name}-lite/*
%config %{_sysconfdir}/logrotate.d/%{name}-lite
%attr(755,root,root) %{_sbindir}/%{name}-lite
%{_datadir}/%{name}-lite/configpath
%{_datadir}/%{name}-lite/functions
%{_datadir}/%{name}-lite/helpers
%{_datadir}/%{name}-lite/lib.*
%{_datadir}/%{name}-lite/modules*
%{_datadir}/%{name}-lite/version
%{_mandir}/man5/%{name}-lite*
%{_mandir}/man8/%{name}-lite*
%{_libexecdir}/%{name}-lite/shorecap
#%{_libexecdir}/%{name}-lite/wait4ifup
%{_unitdir}/shorewall-lite.service

%files ipv6-lite
%doc %{name6}-lite-%{ipv6_lite_ver}/*.txt
%config(noreplace) %{_sysconfdir}/sysconfig/%{name6}-lite
%dir %{_datadir}/%{name6}-lite
%dir %attr(755,root,root) %{_var}/lib/%{name6}-lite
%ghost %{_var}/lib/%{name6}-lite/*
%config(noreplace) %{_sysconfdir}/%{name6}-lite/*
%config %{_sysconfdir}/logrotate.d/%{name6}-lite
%attr(755,root,root) %{_sbindir}/%{name6}-lite
%{_datadir}/%{name6}-lite/configpath
%{_datadir}/%{name6}-lite/functions
%{_datadir}/%{name6}-lite/helpers
%{_datadir}/%{name6}-lite/lib.*
%{_datadir}/%{name6}-lite/modules*
%{_libexecdir}/%{name6}-lite/shorecap
%{_datadir}/%{name6}-lite/version
#%{_datadir}/%{name6}-lite/wait4ifup
%{_mandir}/man5/%{name6}-lite*
%{_mandir}/man8/%{name6}-lite*
%{_unitdir}/shorewall6-lite.service

%files doc
%doc %{name}-docs-html-%{version}/*

%files core
%doc shorewall-core-%{version}/{COPYING,changelog.txt,releasenotes.txt}
%dir %{_datadir}/shorewall/
%{_datadir}/shorewall/coreversion
%{_datadir}/shorewall/functions
%{_datadir}/shorewall/lib.base
%{_datadir}/shorewall/lib.cli
%{_datadir}/shorewall/lib.common
%{_datadir}/shorewall/shorewallrc
#%dir %{_libexecdir}/shorewall
#%{_libexecdir}/shorewall/wait4ifup


%changelog
* Sun Jan 01 2017 luigiwalser <luigiwalser> 5.0.15.2-1.mga6
+ Revision: 1078933
- 5.0.15.2

* Sat Dec 17 2016 luigiwalser <luigiwalser> 5.0.15.1-1.mga6
+ Revision: 1075753
- 5.0.15.1

* Fri Nov 11 2016 luigiwalser <luigiwalser> 5.0.14.1-1.mga6
+ Revision: 1066573
- 5.0.14.1

* Sat Sep 10 2016 luigiwalser <luigiwalser> 5.0.11-1.mga6
+ Revision: 1051350
- 5.0.11

* Wed Aug 10 2016 luigiwalser <luigiwalser> 5.0.10.1-1.mga6
+ Revision: 1045403
- 5.0.10.1

* Thu Jun 23 2016 tmb <tmb> 5.0.9.2-1.mga6
+ Revision: 1037250
- update to 5.0.9.2

* Fri May 06 2016 tmb <tmb> 5.0.8.2-0.1.mga6
+ Revision: 1009743
- update to 5.0.8.2

* Fri Feb 19 2016 umeabot <umeabot> 4.6.13.1-2.mga6
+ Revision: 970282
- Mageia 6 Mass Rebuild

* Fri Oct 02 2015 tmb <tmb> 4.6.13.1-1.mga6
+ Revision: 885694
- update to 4.6.13.1

* Wed Oct 15 2014 umeabot <umeabot> 4.6.3.4-2.mga5
+ Revision: 750832
- Second Mageia 5 Mass Rebuild

* Thu Oct 09 2014 luigiwalser <luigiwalser> 4.6.3.4-1.mga5
+ Revision: 737611
- 4.6.3.4

* Tue Sep 16 2014 umeabot <umeabot> 4.6.3.2-2.mga5
+ Revision: 689142
- Mageia 5 Mass Rebuild

* Fri Sep 05 2014 luigiwalser <luigiwalser> 4.6.3.2-1.mga5
+ Revision: 672328
- 4.6.3.2

* Mon Sep 01 2014 luigiwalser <luigiwalser> 4.6.3.1-1.mga5
+ Revision: 670228
- 4.6.3.1
- rediff patch 6
- add shorewall-mangle man pages to files list

* Thu Mar 13 2014 dams <dams> 4.5.21.7-1.mga5
+ Revision: 603214
- new version 4.5.21.7

  + colin <colin>
    - Drop 'FORMAT 2' in the interfaces files as conflicts with detect mode mga#11928

* Sat Jan 25 2014 colin <colin> 4.5.21.5-1.mga4
+ Revision: 568200
- Update to shorewall 4.5.21.5 to solve parallel ip[6]tables invocations (mga#11928)

* Sat Dec 21 2013 lmenut <lmenut> 4.5.20-3.mga4
+ Revision: 559329
- fix upgrade test in %%post

* Sat Oct 19 2013 umeabot <umeabot> 4.5.20-2.mga4
+ Revision: 533660
- Mageia 4 Mass Rebuild

* Tue Sep 03 2013 oden <oden> 4.5.20-1.mga4
+ Revision: 474647
- 4.5.20
- P6: make it recognize mageia as redhat

* Sat Aug 10 2013 tmb <tmb> 4.5.10.1-5.mga4
+ Revision: 465126
- allow outgoing traffic on any interface by default (mga #10947)

* Tue Feb 05 2013 tmb <tmb> 4.5.10.1-4.mga3
+ Revision: 394718
- fix typo in .restore (P5)

* Sun Feb 03 2013 anssi <anssi> 4.5.10.1-3.mga3
+ Revision: 394246
- remove files from shorewall that conflict with shorewall-core
- versionize requires on shorewall-core
- add missing Conlicts entry due to file moves

* Mon Jan 14 2013 umeabot <umeabot> 4.5.10.1-2.mga3
+ Revision: 381983
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 09 2013 solbu <solbu> 4.5.10.1-1.mga3
+ Revision: 343300
- Fix unpackaged files

  + kamil <kamil>
    - requires shorewall-core by shorewall, -lite and shorewall6 equivalents
    - add /etc/sysconfig/.. to %%files
    - add systemd files to %%files
    - remove 'hash-bang' patch
    - remove dash dependencies
    - try to adjust LIBEXEC
    - adapt .spec for usr move and systemd
    - define SYSTEMD and SBINDIR in ./configure.pl
    - remove P0, P1, P2, P3
    - update %%files
    - new subpackage: shorewall-core
    - disable P0, P1, P2, P3
    - new installation ("Versions 4.5.2 and Later")
    - fix setting ACCOUNTING_TABLE to mangle, there was a typo: ACCOUNT_TABLE
    - don't enable IPV6, it's enabled by default
    - don't set SHOREWALL_COMPILER value - (old, not configrable anymore)
    - stop using versioning requires of iptables (old)
    - remove README.4.4.0.upgrade.urpmi from %%files
    - remove old README.4.4.0.upgrade.urpmi
    - remove old Obsoletes and conflicts
    - new version 4.5.10.1 and update ftp paths

* Mon Apr 09 2012 alien <alien> 4.4.23.1-9.mga2
+ Revision: 229827
- ACCOUNT target allows 0.0.0.0/0

* Sun Apr 08 2012 alien <alien> 4.4.23.1-8.mga2
+ Revision: 229729
- have accounting by default in the mangle table

* Tue Mar 20 2012 blino <blino> 4.4.23.1-7.mga2
+ Revision: 225082
- do not attempt to create /1 file in post script

* Sat Mar 10 2012 kamil <kamil> 4.4.23.1-6.mga2
+ Revision: 222372
- fix license - samples are licensed under LGPLv2.1+
- clean .spec a bit

* Wed Feb 15 2012 lmenut <lmenut> 4.4.23.1-5.mga2
+ Revision: 209012
- allow loading of xz compressed kernel modules

* Sun Jan 08 2012 lmenut <lmenut> 4.4.23.1-4.mga2
+ Revision: 193495
- fix MODULE_SUFFIX (shorewall.conf) in post upgrade
  (complete the fix for mga #1147 and #1903)

* Tue Jan 03 2012 lmenut <lmenut> 4.4.23.1-3.mga2
+ Revision: 189975
- allow to load compressed modules (thanks to Christophe Mace)
  (fix cant connect ftp through firewall - mga #1147)
- really modify default shorewall6.conf

* Sat Dec 03 2011 blino <blino> 4.4.23.1-2.mga2
+ Revision: 175272
- do not try to add LAST LINE comments anymore in config files:
- the command in the spec file was broken (missing leading dir)
- drakx-net will be fixed to deal without these markers

* Mon Sep 12 2011 tv <tv> 4.4.23.1-1.mga2
+ Revision: 142806
- new release
- use function to add comment in config files instead of a patch 4 (tpg)
- drop patch 5 (merged)

* Mon Jun 13 2011 ahmad <ahmad> 4.4.20.2-2.mga2
+ Revision: 105829
- Add a patch from upstream to to quell compiler warnings with perl-5.14 (mga#1775)

* Mon Jun 13 2011 ahmad <ahmad> 4.4.20.2-1.mga2
+ Revision: 105489
- Update to 4.4.20.2

* Sun May 15 2011 pterjan <pterjan> 4.4.19.1-3.mga1
+ Revision: 99032
- Rebuild for fixed find-requires

* Tue May 03 2011 tmb <tmb> 4.4.19.1-2.mga1
+ Revision: 94462
- Add requires on dash as its defined as SHOREWALL_SHELL (mdv #63183)

* Mon Apr 25 2011 ahmad <ahmad> 4.4.19.1-1.mga1
+ Revision: 90647
- Update to 4.4.19.1
- Update the file list
- Rediff the "comment" patch
- Drop the module_suffix patch (Mandriva)

* Fri Feb 11 2011 ennael <ennael> 4.4.12.1-1.mga1
+ Revision: 50105
- remove unused files
- imported package shorewall

